@@ -13,7 +13,7 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Affero General Public License for more details.
  *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
@@ -59,6 +59,7 @@
 #include <osmo-bts/osmux.h>
 #include <osmo-bts/notification.h>
 
+#define MAX_TA_DEF	 63 /* default max Timing Advance value */
 #define MIN_QUAL_RACH	 50 /* minimum link quality (in centiBels) for Access Bursts */
 #define MIN_QUAL_NORM	 -5 /* minimum link quality (in centiBels) for Normal Bursts */
 
@@ -103,6 +104,15 @@ static const struct rate_ctr_desc bts_ctr_desc[] = {
 	[BTS_CTR_AGCH_RCVD] =		{"agch:rcvd", "Received AGCH requests (Abis)"},
 	[BTS_CTR_AGCH_SENT] =		{"agch:sent", "Sent AGCH requests (Abis)"},
 	[BTS_CTR_AGCH_DELETED] =	{"agch:delete", "Sent AGCH DELETE IND (Abis)"},
+
+	[BTS_CTR_RTP_RX_TOTAL] =	{"rtp:rx:total", "Total number of received RTP packets"},
+	[BTS_CTR_RTP_RX_MARKER] =	{"rtp:rx:marker", "Number of received RTP packets with marker bit set"},
+	[BTS_CTR_RTP_RX_DROP_PREEN] =	{"rtp:rx:drop:preen", "Total number of received RTP packets dropped during preening"},
+	[BTS_CTR_RTP_RX_DROP_LOOPBACK] = {"rtp:rx:drop:loopback", "Total number of received RTP packets dropped during loopback"},
+	[BTS_CTR_RTP_RX_DROP_OVERFLOW] = {"rtp:rx:drop:overflow", "Total number of received RTP packets dropped during DL queue overflow"},
+	[BTS_CTR_RTP_RX_DROP_V110_DEC] = {"rtp:rx:drop:v110_dec", "Total number of received RTP packets dropped during V.110 decode"},
+	[BTS_CTR_RTP_TX_TOTAL] =	{"rtp:tx:total", "Total number of transmitted RTP packets"},
+	[BTS_CTR_RTP_TX_MARKER] =	{"rtp:tx:marker", "Number of transmitted RTP packets with marker bit set"},
 };
 static const struct rate_ctr_group_desc bts_ctrg_desc = {
 	"bts",
@@ -344,7 +354,7 @@ int bts_init(struct gsm_bts *bts)
 	bts->bsic_configured = false;
 	bts->load.ccch.load_ind_period = 112;
 	bts->rtp_jitter_buf_ms = 100;
-	bts->max_ta = 63;
+	bts->max_ta = MAX_TA_DEF;
 	bts->ny1 = 4;
 	bts->ny2 = 4;
 	bts->t3105_ms = 300;
@@ -354,8 +364,8 @@ int bts_init(struct gsm_bts *bts)
 	bts->max_ber10k_rach = 1707; /* 7 of 41 bits is Eb/N0 of 0 dB = 0.1707 */
 	bts->pcu.sock_path = talloc_strdup(bts, PCU_SOCK_DEFAULT);
 	bts->pcu.sock_wqueue_len_max = BTS_PCU_SOCK_WQUEUE_LEN_DEFAULT;
-	for (i = 0; i < ARRAY_SIZE(bts->t200_ms); i++)
-		bts->t200_ms[i] = oml_default_t200_ms[i];
+	for (i = 0; i < ARRAY_SIZE(bts->t200_fn); i++)
+		bts->t200_fn[i] = oml_default_t200_fn[i];
 
 	/* default RADIO_LINK_TIMEOUT */
 	bts->radio_link_timeout.oml = 32;
@@ -383,6 +393,10 @@ int bts_init(struct gsm_bts *bts)
 	osmo_bts_set_feature(bts->features, BTS_FEAT_ETWS_PN);
 	osmo_bts_set_feature(bts->features, BTS_FEAT_IPV6_NSVC);
 	osmo_bts_set_feature(bts->features, BTS_FEAT_PAGING_COORDINATION);
+	osmo_bts_set_feature(bts->features, BTS_FEAT_TWTS001);
+
+	/* Maximum TA supported by the PHY (can be overridden by PHY specific code) */
+	bts->support.max_ta = MAX_TA_DEF;
 
 	rc = bts_model_init(bts);
 	if (rc < 0)
